Crate merkle_tree_bulletin_board_backend_mysql

Crate merkle_tree_bulletin_board_backend_mysql 

Structs

BackendMysql
A mysql/mariadb backend for merkle-tree-bulletin-board. This is usable but is not extensively optimized; an expert in mysql/databases/sql could probably improve efficiency.
InvalidHashFormatError

Constants

SCHEMA
The schema used; can be used to initialize the database.

Functions

hash_from_value
Convert v into a HashValue where you know v will be a 32 byte value
opt_hash_from_value
Convert v into a HashValue where you know v will be a 32 byte value or null