Crate merkle_tree_bulletin_board_backend_mysql
merkle_
tree_
bulletin_
board_
backend_
mysql
0.3.0
All Items
Crate Items
Structs
Constants
Functions
Crate
merkle_
tree_
bulletin_
board_
backend_
mysql
Structs

Backend
Mysql
A mysql/mariadb backend for merkle-tree-bulletin-board. This is usable but is not extensively optimized; an expert in mysql/databases/sql could probably improve efficiency.
Invalid
Hash
Format
Error
Constants

SCHEMA
The schema used; can be used to initialize the database.
Functions

hash_
from_
value
Convert v into a HashValue where you know v will be a 32 byte value
opt_
hash_
from_
value
Convert v into a HashValue where you know v will be a 32 byte value or null